pub struct App<S, E>where
S: ContextExt<Context<S>>,{ /* private fields */ }Expand description
build an axum::Router with all routes required for API and admin interface
Implementations
Sourceimpl<S, SE> App<S, SE>where
S: ContextExt<Context<S>> + 'static,
impl<S, SE> App<S, SE>where
S: ContextExt<Context<S>> + 'static,
Sourceimpl<S, SE> App<S, SE>where
S: ContextExt<Context<S>> + 'static,
impl<S, SE> App<S, SE>where
S: ContextExt<Context<S>> + 'static,
pub fn with_mdeditor(self, config: EditorConfig) -> Self
Sourceimpl<S, E> App<S, E>where
S: ContextExt<Context<S>> + 'static,
impl<S, E> App<S, E>where
S: ContextExt<Context<S>> + 'static,
pub fn with_state(self, data: S) -> App<S, S>
Sourceimpl<S, E> App<S, E>where
S: ContextExt<Context<S>> + 'static,
Include the given assets when loading the localized messages
upon a request.
They can then be accessed in any render functions called by
this library (e.g. Column::render
or Input::render_input).
Note: The domain in these functions will still be "derived_cms",
so make sure to add the localized messages to the correct domain
file in the assets.
impl<S, E> App<S, E>where
S: ContextExt<Context<S>> + 'static,
Include the given assets when loading the localized messages
upon a request.
They can then be accessed in any render functions called by
this library (e.g. Column::render
or Input::render_input).
Note: The domain in these functions will still be "derived_cms",
so make sure to add the localized messages to the correct domain
file in the assets.
pub fn include_localizations( self, assets: impl I18nAssets + Send + Sync + 'static, ) -> App<S, E>